Structure
=========

**pyBIMstab** was written under the object-oriented paradigm and is divided into six modules,
one of them contains the class to load and manage the data of the compressibility curve, the other
five contain the classes that solve the nine methods for getting the preconsolidation pressure
or yield stress.

Each module is well documented and contains basic usage examples.

.. toctree::
   :maxdepth: 10

   data
   casagrande
   energy
   bilog
   pachecosilva
   boone

   